import { world, system } from "@minecraft/server";

// Evento que ocorre quando uma entidade é atacada
world.afterEvents.entityHitEntity.subscribe((data) => {
    const { damagingEntity, hitEntity } = data;

    // Verifica se quem causou o dano é um jogador
    if (damagingEntity.typeId !== "minecraft:player") return;

    // Obtém o item na mão principal do jogador
    const equipment = damagingEntity.getComponent("equippable").getEquipment("Mainhand");

    // Verifica se o item é uma tesoura e o mob atingido é uma ovelha nomeada "jeb_"
    if (equipment && equipment.typeId === "minecraft:shears" && hitEntity.typeId === "minecraft:sheep" && hitEntity.nameTag === "jeb_") {
        // Verifica se a ovelha já tem a tag "sheared"
        const testForTagCommand = `testfor @e[type=minecraft:sheep,name=jeb_,r=1,tag=sheared]`;

        hitEntity.runCommandAsync(testForTagCommand).then((result) => {
            if (result.successCount === 0) {
                // Adiciona a tag "sheared" à ovelha
                hitEntity.runCommandAsync('tag @s add sheared');
                // Executa o comando /event entity no mob atingido
                hitEntity.runCommandAsync('event entity @s minecraft:on_sheared');
                hitEntity.runCommandAsync('structure load rainbow_drop ~~1~');
                // Reproduz o som de tesoura
                damagingEntity.runCommandAsync('playsound mob.sheep.shear @s');
            } else {
                // Feedback visual no chat informando que a ovelha já foi tosada
                damagingEntity.runCommandAsync('/title @s actionbar §4The sheep has already been sheared');
                damagingEntity.runCommandAsync('playsound note.bass @s');

            }
        }).catch((error) => {
            console.error('Erro ao verificar a tag "sheared":', error);
        });
    }
});

// Verificação periódica para remover a tag "sheared" quando a lã crescer
system.runInterval(() => {
    const sheepEntities = world.getDimension("overworld").getEntities({ type: "minecraft:sheep" });

    sheepEntities.forEach(sheep => {
        if (sheep.nameTag === "jeb_" && sheep.hasTag("sheared")) {
            // Verifica se a ovelha regenerou a lã (não está mais tosada)
            if (!sheep.hasComponent("minecraft:is_sheared")) {
                // Remove a tag "sheared"
                sheep.runCommandAsync('tag @s remove sheared');
            }
        }
    });
}, 1); // Verifica a cada segundo (20 ticks)

system.runInterval(() => {
    const sheepEntities = world.getDimension("overworld").getEntities({ type: "minecraft:sheep" });

    sheepEntities.forEach(sheep => {
        if (sheep.nameTag === "jeb_" && sheep.hasTag("sheared")) {
            // Verifica se a ovelha regenerou a lã (não está mais tosada)
            if (!sheep.hasComponent("minecraft:is_sheared")) {
                // Remove a tag "sheared"
                sheep.runCommandAsync('tag @s remove sheared');
            }
        }
    });
}, 1); // Verifica a cada segundo (20 ticks)

system.runInterval(() => {
    const itemToCheck = 'minecraft:shears'; // Item a ser verificado

    // Comando para verificar se um jogador tem o item
    const testForCommand = `testfor @a[hasitem={item=${itemToCheck},location=slot.weapon.mainhand}]`;
    const testForCommand2 = `testfor @e[type=sheep,name=jeb_,r=6]`;

    world.getAllPlayers().forEach(player => {
        player.runCommandAsync(testForCommand).then((result) => {
            if (result.successCount > 0) {

                player.runCommandAsync(testForCommand2).then((result) => {
                    if (result.successCount > 0) {

                        player.runCommand(`/effect @s weakness 1 250 true`);

                    }
                })
            }
        }).catch((error) => {
            console.error(`Erro ao executar o comando: ${error}`);
        });
    });
}, 1); // Verifica a cada segundo (20 ticks)